@@ -1,6 +1,9 @@
 from typing import Dict, Any, List, Optional
+import logging
 
 from .entities import Template, Letter
+from .utils import get_debug_mode
+
 
 __all__ = (
     'send_mail',
@@ -32,15 +35,21 @@ def send_mail(
     if attachments is None:
         attachments = []
 
-    template = Template.from_event(event)
-    letter = template.new_letter(
-        context=context,
-        recipients=recipients,
-        email_from=from_email,
-        attachments=attachments,
-        language=language
-    )
+    try:
+        template = Template.from_event(event)
+        letter = template.new_letter(
+            context=context,
+            recipients=recipients,
+            email_from=from_email,
+            attachments=attachments,
+            language=language
+        )
 
-    letter.send(backend)
+        letter.send(backend)
+        return letter
+    except Exception as e:
+        if get_debug_mode():
+            logging.exception('SEND MAIL EXCEPTION')
+        else:
+            raise e
 
-    return letter
