@@ -58,17 +58,9 @@ TEMPLATES = [
     },
 ]
 
-# DATABASES = {
-#     'default': env.db('DATABASE_URL', default='postgres://postgres:@localhost:5432/postie')
-
-# }
-import os
-
 DATABASES = {
-    'default': {
-        'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
-    }
+    'default': env.db('DATABASE_URL', default='postgres://postgres:@localhost:5432/postie')
+
 }
 
 TIME_ZONE = 'UTC'
@@ -100,6 +92,7 @@ POSTIE_TEMPLATE_CONTEXTS = {
 
 POSTIE_INSTANT_SEND = True
 POSTIE_TASK_COUNTDOWN = 5
+POSTIE_DEBUG_MODE = False
 
 PARLER_LANGUAGES = {
     1: (
